@@ -10,8 +10,8 @@ type t =
 
 # 1 "runtime/caml/domain_state.tbl" 1
 # 17 "runtime/caml/domain_state.tbl"
-| Domain_young_ptr
 | Domain_young_limit
+| Domain_young_ptr
 
 
 | Domain_exception_pointer
@@ -32,6 +32,9 @@ type t =
 | Domain_custom_table
 
 
+| Domain_mark_stack
+
+
 | Domain_stack_low
 | Domain_stack_high
 | Domain_stack_threshold
@@ -67,7 +70,15 @@ type t =
 | Domain_stat_heap_wsz
 | Domain_stat_top_heap_wsz
 | Domain_stat_compactions
+| Domain_stat_forced_major_collections
 | Domain_stat_heap_chunks
+
+
+| Domain_eventlog_startup_timestamp
+| Domain_eventlog_startup_pid
+| Domain_eventlog_paused
+| Domain_eventlog_enabled
+| Domain_eventlog_out
 # 20 "utils/domainstate.mli.c" 2
 
 
